==> apeman-dev-commons-testing-1.3.0.tgz: package/ci/build.js <==
#!/usr/bin/env node

/**
 * @file Build this project.
 */

"use strict";


var coz = require('coz'),
    path = require('path'),
    async = require('async');

var pkg = require('../package.json'),
    tmpl = require("apeman-tmpl-contrib-official/lib/commons");

var basedir = path.resolve(__dirname, '..');

process.chdir(basedir);

async.series([
    function (callback) {
        coz.render([
            //"lib/**/.*.bud",
            "test/**/.*.bud"
        ], callback);
    },
    function (callback) {
        tmpl.render({
            pkg: pkg,
            ignore: [],
            year: new Date().getFullYear(),
            modules: [
                {
                    "name": "runNodeunit"
                },
                {
                    "name":"runKarma"
                }
            ],
            usages: [
                {
                    "title": "runNodeunit",
                    "description": "Release a package.",
                    "example": "docs/examples/run-nodeunit-example.js"
                },
                {
                    "title":"runKarma",
                    "description":"Run karma test.",
                    "example":"docs/examples/run-karma-example.js"
                }
            ],
            see: {
                'karma': 'http://karma-runner.github.io/',
                'nodeunit': 'https://github.com/caolan/nodeunit'
            }
        }, callback);
    }
], function (err) {
    if (err) {
        console.error(err);
    }
});

==> apeman-dev-commons-testing-1.3.4.tgz: package/ci/build.js <==
#!/usr/bin/env node

/**
 * @file Build this project.
 */

"use strict";


var coz = require('coz'),
    path = require('path'),
    async = require('async');

var pkg = require('../package.json'),
    tmpl = require("apeman-tmpl-contrib-official/lib/commons");

var basedir = path.resolve(__dirname, '..');

process.chdir(basedir);

async.series([
    function (callback) {
        coz.render([
            //"lib/**/.*.bud",
            "test/**/.*.bud"
        ], callback);
    },
    function (callback) {
        tmpl.render({
            pkg: pkg,
            ignore: [],
            year: new Date().getFullYear(),
            modules: [
                {
                    "name": "runNodeunit"
                },
                {
                    "name": "runMocha"
                }
            ],
            usages: [
                {
                    "title": "runNodeunit",
                    "description": "Run nodeunit test.",
                    "example": "docs/examples/run-nodeunit-example.js"
                },
                {
                    "title": "runMocha",
                    "description": "Run mocha test.",
                    "example": "docs/examples/run-mocha-example.js"
                }
            ],
            see: {
                'mocha': 'https://www.npmjs.com/package/mocha',
                'nodeunit': 'https://github.com/caolan/nodeunit'
            }
        }, callback);
    }
], function (err) {
    if (err) {
        console.error(err);
    }
});
